@@ -32,9 +32,10 @@ extensions = [
 ]
 
 # openstackdocstheme options
-repository_name = 'openstack/networking-bgpvpn'
-bug_project = 'bgpvpn'
-bug_tag = ''
+openstackdocs_repo_name = 'openstack/networking-bgpvpn'
+openstackdocs_pdf_link = True
+openstackdocs_bug_project = 'bgpvpn'
+openstackdocs_bug_tag = ''
 
 # autodoc generation is a bit aggressive and a nuisance when doing heavy
 # text edit cycles.
@@ -47,7 +48,7 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General information about the project.
-copyright = u'2013, OpenStack Foundation'
+copyright = '2013, OpenStack Foundation'
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
 add_function_parentheses = True
@@ -57,7 +58,7 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 # Example configuration for intersphinx: refer to the Python standard library.
 #intersphinx_mapping = {'http://docs.python.org/': None}
@@ -76,8 +77,6 @@ blockdiag_html_image_format = "svg"
 html_static_path = ['_static']
 html_theme = 'openstackdocs'
 
-html_last_updated_fmt = '%Y-%m-%d %H:%M'
-
 # -- Options for LaTeX output -------------------------------------------------
 
 # Grouping the document tree into LaTeX files. List of tuples
@@ -86,8 +85,8 @@ html_last_updated_fmt = '%Y-%m-%d %H:%M'
 latex_documents = [
     ('index',
      'doc-networking-bgpvpn.tex',
-     u'Networking BGPVPN Documentation',
-     u'OpenStack Foundation', 'manual'),
+     'Networking BGPVPN Documentation',
+     'OpenStack Foundation', 'manual'),
 ]
 
 latex_elements = {
